@@ -55,5 +55,5 @@ pub fn zest4096(input: ZestBlock) -> ZestBlock {
         eighth_round((6, 15, 16, 25, 34, 43, 52, 61), x);
         eighth_round((7, 8, 17, 26, 35, 44, 53, 62), x);
     }
-    output_block + input
+    output_block ^ input
 }
